# -*- coding: utf-8 -*-

__copyright__ = """ Copyright (c) 2011-2013 Torsten Schmits

This program is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, see <http://www.gnu.org/licenses/>.
"""

import os

from tek import logger
from tek.config import lazy_configurable, Configurations

from series import store_episode
from series.daemon.errors import ArchiverError
from series.daemon.handler import Handler


@lazy_configurable(series=['series_dir'], daemon=['path_template'])
class Archiver(Handler):

    def __init__(self, queue, commit):
        super(Archiver, self).__init__(queue, commit, 5, 'archiver')
        Configurations.override('store_episode', overwrite=True)

    def _qualify(self, release):
        return (not (release.unknown or release.archived or
                     release.archiver_error)
                and release.downloaded)

    def _handle(self, monitor):
        release = monitor.release
        logger.info(u'Archiving {!s}.'.format(release))
        handler = store_episode.EpisodeHandler(ask=False,
                                               series_name=release.name)
        try:
            if monitor.download_path:
                local_path = self._format_path(monitor)
                dest_path = os.path.join(self._series_dir, local_path)
                handler.add_job(monitor.download_path, dest_path)
            if not os.path.isfile(monitor.download_path):
                text = u'Downloaded release "{!s}" missing!'
                if os.path.isfile(dest_path):
                    text += u'\nHowever, it seems to be archived.'
                    monitor.archived = True
                raise ArchiverError(text.format(release))
            stored = handler.store()
            if stored:
                monitor.archived = True
        except store_episode.errors.UnknownSeries as e:
            logger.error(e)
            monitor.unknown = True
        except ArchiverError as e:
            logger.error(e)
            monitor.archiver_error = True
        self._commit()

    def _format_path(self, monitor):
        parts = monitor.download_path.rsplit('.', 1)
        release = monitor.release
        if len(parts) <= 1:
            logger.error('Invalid filename. Assuming \'mkv\' extension.')
            extension = 'mkv'
        else:
            extension = parts[1]
        parameters = dict(
            name=release.name,
            season=release.season,
            episode=release.episode,
            ext=extension,
        )
        local = self._path_template.format(**parameters)
        return os.path.join(self._series_dir, local)
