""" configuration for daemon """

__copyright__ = """ Copyright (c) 2011-2013 Torsten Schmits

This program is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, see <http://www.gnu.org/licenses/>.
"""

import os

from tek.config import (Configurations, PathConfigOption, ListConfigOption,
                        FileSizeConfigOption)

try:
    from series.config import reset_config as s_reset_config
    __has_parent__ = True
except ImportError:
    __has_parent__ = False

def reset_config(register_files=True, reset_parent=False):
    """ Initialize the config. """
    if __has_parent__ and reset_parent:
        s_reset_config(register_files=register_files, reset_parent=reset_parent)
    path_template = '{name}/s{season}/{name}_{season:0>2}x{episode:0>2}.{ext}'
    Configurations.register_config(
        'series',
        'daemon',
        rss_urls=ListConfigOption(),
        rss_interval=15 * 60,
        download_dir=PathConfigOption(os.getcwd()),
        run_downloader=True,
        run_archiver=True,
        run_dbus_service=True,
        run_subsyncer=True,
        run_feed_poller=True,
        cli_cmd=None,
        cli_params=[],
        use_sharehosters=True,
        use_torrent=False,
        torrent_launcher='transmission-remote -a {}',
        min_size=FileSizeConfigOption(),
        path_template=path_template,
    )
    Configurations.override('store_episode', match_threshold=1., overwrite=True)
reset_config()
