__copyright__ = """ Copyright (c) 2013 Torsten Schmits

This program is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, see <http://www.gnu.org/licenses/>.
"""

import time
from threading import Thread
from datetime import datetime, timedelta

import sqlalchemy

from tek import logger
from tek.tools import find

class Handler(Thread):

    def __init__(self, queue, commit, interval, description):
        self._queue = queue
        self._commit = commit
        self._interval = interval
        self._description = description
        super(Handler, self).__init__()
        self._running = True

    def run(self):
        logger.info('Starting {}.'.format(self._description))
        next_check = datetime.now() + timedelta(seconds=5)
        while self._running:
            if datetime.now() > next_check:
                current = self._current
                if current is not None:
                    self._handle(current)
                next_check = self._next_check
            time.sleep(1)

    def stop(self):
        self._running = False

    @property
    def _next_check(self):
       return datetime.now() + timedelta(seconds=self._interval) 

    def _handle(self, monitor):
        pass

    @property
    def _current(self):
        try:
            return find(self._qualify, self._candidates)
        except sqlalchemy.exc.InvalidRequestError:
            pass

    def _qualify(self, release):
        return True

    @property
    def _candidates(self):
        return self._queue

__all__ = []
