# -*- coding: utf-8 -*-

__copyright__ = """ Copyright (c) 2013 Torsten Schmits

This program is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, see <http://www.gnu.org/licenses/>.
"""

from tek.config import lazy_configurable
from tek import logger

from series import subsync
from series.daemon.handler import Handler
from series.subsync.errors import NoSubsForEpisode

@lazy_configurable(series=['series_dir'])
class Subsyncer(Handler):

    def __init__(self, queue, commit):
        super(Subsyncer, self).__init__(queue, commit, 5,
                                        'subtitle downloader')

    def _qualify(self, monitor):
        return (monitor.archived and not monitor.subtitles_downloaded and not
                getattr(monitor, 'subs_missing', False))

    def _handle(self, monitor):
        release = monitor.release
        text = u'Downloading subs for episode {!s}…'
        logger.info(text.format(release))
        try:
            subsync.get_episode(release.name, release.season, release.episode)
        except NoSubsForEpisode as e:
            logger.error(e)
            monitor.subs_missing = True
        else:
            monitor.subtitles_downloaded = True
            logger.info('Successfully downloaded subtitles.')

__all__ = ['Subsyncer']
