__copyright__ = """ Copyright (c) 2013 Torsten Schmits

This program is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, see <http://www.gnu.org/licenses/>.
"""

import os
import re

from tek.config import lazy_configurable
from tek.config.errors import ConfigError
from tek.process import process_output
from tek.tools import find
from tek import logger


def _is_etvdb(fpath):
    rex = re.compile('Gstaedtner')
    return find(rex.search, process_output([fpath, '-C']))


class ETVDBExecutable(object):
    fallback = '/usr/bin/etvdb_cli'

    def __init__(self, path):
        self._path = self._validate_executable(path)

    def _validate_executable(self, path):
        for fpath in [path, self.fallback]:
            if (os.path.isfile(fpath) and os.access(fpath, os.X_OK) and
                    _is_etvdb(fpath)):
                return fpath
        raise ConfigError('ETVDB executable not found!')


@lazy_configurable(etvdb=['path'])
class ETVDB(object):

    def __init__(self):
        self._executable = ETVDBExecutable(self._path)

__all__ = []
