from __future__ import absolute_import

__copyright__ = """ Copyright (c) 2011-2013 Torsten Schmits

This program is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, see <http://www.gnu.org/licenses/>.
"""

import shutil
import os

from unittest import TestCase

from tek import Configurations, debug
from tek.user_input import input_queue

from series.handle_episode import EpisodeHandler, config
from series.store_episode import config as st_config
from series.subsync import config as ss_config
from tek_utils.extract import config as e_config

class EpisodeTest(TestCase):

    def setUp(self):
        Configurations.clear()
        config.reset_config(reset_parent=True)
        e_config.reset_config()
        st_config.reset_config()
        ss_config.reset_config()
        self._temp = 'test/data/handle_episode/temp'
        self._series = 'test/data/handle_episode/series'
        shutil.rmtree(self._temp)
        shutil.rmtree(self._series)
        os.mkdir(self._temp)
        os.mkdir(self._series)

    def test_dir(self):
        Configurations.override('series', temp_dir=self._temp, series_dir=self._series)
        input_queue.push('q', 'y', 'q')
        os.mkdir(os.path.join(self._series, 'dexter'))
        os.mkdir(os.path.join(self._series, 'game_of_thrones'))
        os.mkdir(os.path.join(self._series, 'subtitle'))
        os.mkdir(os.path.join(self._series, 'title'))
        handler = EpisodeHandler(pretend_delete=True)
        handler.handle_episodes(['test/data/handle_episode'])
        epis = sorted(handler._episodes, key=lambda f: f.filename)
        self.assertFalse(epis[0].valid)
        self.assertTrue(os.path.isfile(os.path.join(self._series, 'title', 's1',
                                                    'sub', 'title_01x02.srt')))
        self.assertFalse(epis[3].complete)
